==> beigesoft-webcrud-jar-1.1.5-src.tar.bz2: src/main/java/org/beigesoft/web/servlet/WChangeUserPasswd.java <==
package org.beigesoft.web.servlet;

/*
 * Copyright (c) 2018 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.beigesoft.exception.ExceptionWithCode;
import org.beigesoft.web.service.SrvAddTheFirstUser;

/**
 * <p>Servlet that change user password.
 * For LOCALHOST only!</p>
 * @author Yury Demidenko
 */
@SuppressWarnings("serial")
public class WChangeUserPasswd extends HttpServlet {

  @Override
  public final void doPost(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    pReq.setCharacterEncoding("UTF-8");
    pResp.setCharacterEncoding("UTF-8");
    try {
      @SuppressWarnings("rawtypes")
      SrvAddTheFirstUser srvAddFiU = (SrvAddTheFirstUser) getServletContext()
        .getAttribute("srvAddTheFirstUser");
      String userName = pReq.getParameter("userName");
      String userPassOld = pReq.getParameter("userPassOld");
      String userPass = pReq.getParameter("userPass");
      String userPassRep = pReq.getParameter("userPassRep");
      String jsp = "/secure/changePasswdFirstUser.jsp";
      if (userName == null) {
        pReq.setAttribute("passwErrMsg", "enterName");
      } else if (userPassOld != null && userPassOld.equals(userPass)) {
        pReq.setAttribute("passwErrMsg", "pass_new_same_old");
      } else if (userPass == null) {
        pReq.setAttribute("passwErrMsg", "passwNotStrong");
      } else if (!userPass.equals(userPassRep)) {
        pReq.setAttribute("passwErrMsg", "repeatPasswNotMatch");
      } else if (userPass.contains(userName)) {
        pReq.setAttribute("passwErrMsg", "passwMustNoContainName");
      } else {
        String chkps = srvAddFiU.isPasswordStrong(userPass.toCharArray());
        if (chkps != null) {
          pReq.setAttribute("passwErrMsg", chkps);
        } else {
          if (!srvAddFiU.changeUserPasswd(userName, userPass, userPassOld)) {
            pReq.setAttribute("passwErrMsg", "invalid_user_name_or_password");
          } else {
            jsp = "/secure/main.jsp";
            pReq.getSession().invalidate();
          }
        }
      }
      RequestDispatcher rd = getServletContext().getRequestDispatcher(jsp);
      rd.include(pReq, pResp);
    } catch (Exception e) {
      e.printStackTrace();
      if (e instanceof ExceptionWithCode) {
        pReq.setAttribute("error_code",
          ((ExceptionWithCode) e).getCode());
        pReq.setAttribute("short_message",
          ((ExceptionWithCode) e).getShortMessage());
      } else {
        pReq.setAttribute("error_code",
          HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      }
      pReq.setAttribute("javax.servlet.error.status_code",
        HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      pReq.setAttribute("javax.servlet.error.exception", e);
      pReq.setAttribute("javax.servlet.error.request_uri",
        pReq.getRequestURI());
      pReq.setAttribute("javax.servlet.error.servlet_name", this.getClass()
        .getCanonicalName());
      pResp.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
    }
  }
}

==> beigesoft-webcrud-jar-1.1.7-src.tar.bz2: src/main/java/org/beigesoft/web/servlet/WChangeUserPasswd.java <==
package org.beigesoft.web.servlet;

/*
 * Copyright (c) 2018 Beigesoft ™
 *
 * Licensed under the GNU General Public License (GPL), Version 2.0
 * (the "License");
 * you may not use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html
 */

import java.util.HashMap;
import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.beigesoft.exception.ExceptionWithCode;
import org.beigesoft.web.service.SrvAddTheFirstUser;
import org.beigesoft.web.service.ILstnUserPswdChanged;
import org.beigesoft.log.ILogger;
import org.beigesoft.web.model.HttpRequestData;
import org.beigesoft.handler.IHandlerRequest;
import org.beigesoft.factory.IFactoryAppBeans;

/**
 * <p>Servlet that change user password.
 * For LOCALHOST only!</p>
 * @author Yury Demidenko
 */
@SuppressWarnings("serial")
public class WChangeUserPasswd extends HttpServlet {

  @Override
  public final void doPost(final HttpServletRequest pReq,
    final HttpServletResponse pResp) throws ServletException, IOException {
    pReq.setCharacterEncoding("UTF-8");
    pResp.setCharacterEncoding("UTF-8");
    IFactoryAppBeans factoryAppBeans = null;
    try {
      HashMap<String, Object> reqVars = new HashMap<String, Object>();
      factoryAppBeans = (IFactoryAppBeans) getServletContext()
          .getAttribute("IFactoryAppBeans");
      HttpRequestData requestData = new HttpRequestData(pReq, pResp);
      requestData.setAttribute("reqVars", reqVars);
      IHandlerRequest hndlI18nRequest = (IHandlerRequest)
        factoryAppBeans.lazyGet("hndlI18nRequest");
      hndlI18nRequest.handle(reqVars, requestData);
      @SuppressWarnings("rawtypes")
      SrvAddTheFirstUser srvAddFiU = (SrvAddTheFirstUser) getServletContext()
        .getAttribute("srvAddTheFirstUser");
      String userName = pReq.getParameter("userName");
      String userPassOld = pReq.getParameter("userPassOld");
      String userPass = pReq.getParameter("userPass");
      String userPassRep = pReq.getParameter("userPassRep");
      String jsp = "/secure/jspd?nmRnd=changePasswdFirstUser";
      if (userName == null) {
        pReq.setAttribute("passwErrMsg", "enterName");
      } else if (userPassOld != null && userPassOld.equals(userPass)) {
        pReq.setAttribute("passwErrMsg", "pass_new_same_old");
      } else if (userPass == null) {
        pReq.setAttribute("passwErrMsg", "passwNotStrong");
      } else if (!userPass.equals(userPassRep)) {
        pReq.setAttribute("passwErrMsg", "repeatPasswNotMatch");
      } else if (userPass.contains(userName)) {
        pReq.setAttribute("passwErrMsg", "passwMustNoContainName");
      } else {
        String chkps = srvAddFiU.isPasswordStrong(userPass.toCharArray());
        if (chkps != null) {
          pReq.setAttribute("passwErrMsg", chkps);
        } else {
          if (!srvAddFiU.changeUserPasswd(userName, userPass, userPassOld)) {
            pReq.setAttribute("passwErrMsg", "invalid_user_name_or_password");
          } else {
            jsp = null;
            pReq.getSession().invalidate();
            ILstnUserPswdChanged lstn = (ILstnUserPswdChanged)
              getServletContext().getAttribute("ILstnUserPswdChanged");
            if (lstn != null) {
              lstn.passwordChanged(userName);
            }
          }
        }
      }
      if (jsp == null) {
        pResp.sendRedirect("../");
      } else {
        RequestDispatcher rd = getServletContext().getRequestDispatcher(jsp);
        rd.include(pReq, pResp);
      }
    } catch (Exception e) {
      if (factoryAppBeans != null) {
        ILogger logger = null;
        try {
          logger = (ILogger) factoryAppBeans.lazyGet("ILogger");
        } catch (Exception e1) {
          e1.printStackTrace();
        }
        if (logger != null) {
          logger.error(null, getClass(), "WORK", e);
        } else {
          e.printStackTrace();
        }
      } else {
        e.printStackTrace();
      }
      if (e instanceof ExceptionWithCode) {
        pReq.setAttribute("error_code",
          ((ExceptionWithCode) e).getCode());
        pReq.setAttribute("short_message",
          ((ExceptionWithCode) e).getShortMessage());
      } else {
        pReq.setAttribute("error_code",
          HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      }
      pReq.setAttribute("javax.servlet.error.status_code",
        HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
      pReq.setAttribute("javax.servlet.error.exception", e);
      pReq.setAttribute("javax.servlet.error.request_uri",
        pReq.getRequestURI());
      pReq.setAttribute("javax.servlet.error.servlet_name", this.getClass()
        .getCanonicalName());
      pResp.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
    }
  }
}
